@@ -522,6 +522,9 @@ class Progress(Base):
     controll_type_id = Column(ForeignKey('univer_controll_type.controll_type_id'))
     controll_type = relationship('ControllType')
 
+    # Часы
+    hours = Column('progress_hours', Integer)
+
     # Статус
     status = Column(Integer)
 
@@ -549,4 +552,4 @@ class Country(Base):
         return '<Country {}>'.format(self)
     
     def __str__(self):
-        return self.name_ru
\ No newline at end of file
+        return self.name_ru
